import marshmallow as ma

from .common_collection_schema import CommonCollectionSchema


class MappedCollectionCommonSchema(CommonCollectionSchema):
    """
    Transfer's view of a mapped collection
    """

    DATA_TYPE = ma.fields.String(default="endpoint")
    public = ma.fields.Boolean(default=True)
    myproxy_server = ma.fields.Constant("myproxy.globusonline.org")
    disable_anonymous_writes = ma.fields.Boolean()
    s3_requester_pays = ma.fields.Boolean(data_key="requester_pays")
    network_use = ma.fields.String(
        validate=[ma.validate.OneOf(["normal", "minimal", "aggressive", "custom"])],
        allow_none=True,
        attribute="storage_gateway.network_use",
    )
    max_concurrency = ma.fields.Int(
        validate=[ma.validate.Range(min=1)], attribute="storage_gateway.max_concurrency"
    )
    preferred_concurrency = ma.fields.Int(
        validate=[ma.validate.Range(min=1)],
        attribute="storage_gateway.preferred_concurrency",
    )

    max_parallelism = ma.fields.Int(
        validate=[ma.validate.Range(min=1)], attribute="storage_gateway.max_parallelism"
    )
    preferred_parallelism = ma.fields.Int(
        validate=[ma.validate.Range(min=1)],
        attribute="storage_gateway.preferred_parallelism",
    )


class MappedCollectionUpdateSchema(MappedCollectionCommonSchema):
    last_accessed_time = ma.fields.DateTime()


class MappedCollectionCreateSchema(MappedCollectionCommonSchema):
    gcs_private_uuid = ma.fields.UUID()
    gcs_private_parent_endpoint_id = ma.fields.UUID()


mapped_collection_create_schema = MappedCollectionCreateSchema()
mapped_collection_update_schema = MappedCollectionUpdateSchema()
